cmoncrawl.processor.pipeline.streamer.StreamerDummy.clean\_up
=============================================================

.. currentmodule:: cmoncrawl.processor.pipeline.streamer

.. automethod:: StreamerDummy.clean_up